@@ -1,7 +1,7 @@
 package Setup::Unix::Group;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010;
 use strict;
@@ -279,7 +279,7 @@ Setup::Unix::Group - Setup Unix group (existence)
 
 =head1 VERSION
 
-This document describes version 0.12 of Setup::Unix::Group (from Perl distribution Setup-Unix-User), released on 2015-08-18.
+This document describes version 0.13 of Setup::Unix::Group (from Perl distribution Setup-Unix-User), released on 2015-09-04.
 
 =head1 FAQ
 
@@ -294,7 +294,7 @@ L<Setup::Unix::User>
 
 =head2 addgroup(%args) -> [status, msg, result, meta]
 
-{en_US Add group}.
+Add group.
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -305,44 +305,38 @@ Arguments ('*' denotes required arguments):
 
 =item * B<etc_dir> => I<str> (default: "/etc")
 
-{en_US Location of passwd files}.
+Location of passwd files.
 
 =item * B<gid> => I<int>
 
-{en_US Add with specified GID}.
+Add with specified GID.
 
-{en_US 
 If not specified, will search an unused GID from C<min_new_gid> to C<max_new_gid>.
 
 If specified, will accept non-unique GID (that which has been used by other
 group).
-}
 
 =item * B<group> => I<str>
 
-{en_US Group name}.
+Group name.
 
 =item * B<max_gid> => I<int> (default: 65534)
 
-{en_US Specify range for new GID}.
+Specify range for new GID.
 
-{en_US 
 If a free GID between C<min_gid> and C<max_gid> is not available, an error is
 returned.
 
 Passed to Unix::Passwd::File's C<max_new_gid>.
-}
 
 =item * B<min_gid> => I<int> (default: 1000)
 
-{en_US Specify range for new GID}.
+Specify range for new GID.
 
-{en_US 
 If a free GID between C<min_gid> and C<max_gid> is not available, an error is
 returned.
 
 Passed to Unix::Passwd::File's C<min_new_gid>.
-}
 
 =back
 
@@ -386,13 +380,11 @@ Return value:  (any)
 
 =head2 delgroup(%args) -> [status, msg, result, meta]
 
-{en_US Delete group}.
+Delete group.
 
-{en_US 
 Fixed state: group does not exist.
 
 Fixable state: group exists.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -403,11 +395,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<etc_dir> => I<str> (default: "/etc")
 
-{en_US Location of passwd files}.
+Location of passwd files.
 
 =item * B<group> => I<str>
 
-{en_US Group name}.
+Group name.
 
 =back
 
@@ -451,9 +443,8 @@ Return value:  (any)
 
 =head2 setup_unix_group(%args) -> [status, msg, result, meta]
 
-{en_US Setup Unix group (existence)}.
+Setup Unix group (existence).
 
-{en_US 
 On do, will create Unix group if not already exists. The created GID will be
 returned in the result (C<< {gid =E<gt> GID} >>). If C<should_already_exist> is set to
 true, won't create but only require that group already exists. If C<should_exist>
@@ -462,7 +453,6 @@ is set to false, will delete existing group instead of creating it.
 On undo, will delete Unix group previously created.
 
 On redo, will recreate the Unix group with the same GID.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -473,52 +463,46 @@ Arguments ('*' denotes required arguments):
 
 =item * B<etc_dir> => I<str> (default: "/etc")
 
-{en_US Location of passwd files}.
+Location of passwd files.
 
 =item * B<group> => I<str>
 
-{en_US Group name}.
+Group name.
 
 =item * B<max_new_gid> => I<int> (default: 65534)
 
-{en_US Specify range for new GID}.
+Specify range for new GID.
 
-{en_US 
 If a free GID between C<min_gid> and C<max_gid> is not available, an error is
 returned.
 
 Passed to Unix::Passwd::File's C<max_new_gid>.
-}
 
 =item * B<min_new_gid> => I<int> (default: 1000)
 
-{en_US Specify range for new GID}.
+Specify range for new GID.
 
-{en_US 
 If a free GID between C<min_gid> and C<max_gid> is not available, an error is
 returned.
 
 Passed to Unix::Passwd::File's C<min_new_gid>.
-}
 
 =item * B<new_gid> => I<int>
 
-{en_US Add with specified GID}.
+Add with specified GID.
 
-{en_US 
 If not specified, will search an unused GID from C<min_new_gid> to C<max_new_gid>.
 
 If specified, will accept non-unique GID (that which has been used by other
 group).
-}
 
 =item * B<should_already_exist> => I<bool>
 
-{en_US Whether group should already exist}.
+Whether group should already exist.
 
 =item * B<should_exist> => I<bool> (default: 1)
 
-{en_US Whether group should exist}.
+Whether group should exist.
 
 =back
 
