@@ -1,7 +1,7 @@
 package Setup::Unix::User;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -511,7 +511,7 @@ Setup::Unix::User - Setup Unix user (existence, home dir, group memberships)
 
 =head1 VERSION
 
-This document describes version 0.12 of Setup::Unix::User (from Perl distribution Setup-Unix-User), released on 2015-08-18.
+This document describes version 0.13 of Setup::Unix::User (from Perl distribution Setup-Unix-User), released on 2015-09-04.
 
 =head1 FAQ
 
@@ -534,7 +534,7 @@ L<Setup::Unix::Group>
 
 =head2 add_delete_user_groups(%args) -> [status, msg, result, meta]
 
-{en_US Add/delete user from group memberships}.
+Add/delete user from group memberships.
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -549,11 +549,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<etc_dir> => I<str> (default: "/etc")
 
-{en_US Location of passwd files}.
+Location of passwd files.
 
 =item * B<user> => I<str>
 
-{en_US User name}.
+User name.
 
 =back
 
@@ -597,7 +597,7 @@ Return value:  (any)
 
 =head2 adduser(%args) -> [status, msg, result, meta]
 
-{en_US Add user}.
+Add user.
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -608,21 +608,19 @@ Arguments ('*' denotes required arguments):
 
 =item * B<etc_dir> => I<str> (default: "/etc")
 
-{en_US Location of passwd files}.
+Location of passwd files.
 
 =item * B<gecos> => I<str>
 
 =item * B<gid> => I<int>
 
-{en_US When creating group, use specific GID}.
+When creating group, use specific GID.
 
-{en_US 
 If not specified, will search an unused GID from C<min_gid> to C<max_gid>.
-}
 
 =item * B<group> => I<str>
 
-{en_US Group name}.
+Group name.
 
 =item * B<home> => I<str>
 
@@ -640,15 +638,13 @@ If not specified, will search an unused GID from C<min_gid> to C<max_gid>.
 
 =item * B<uid> => I<int>
 
-{en_US Add with specified UID}.
+Add with specified UID.
 
-{en_US 
 If not specified, will search an unused UID from C<min_uid> to C<max_uid>.
-}
 
 =item * B<user> => I<str>
 
-{en_US User name}.
+User name.
 
 =back
 
@@ -692,7 +688,7 @@ Return value:  (any)
 
 =head2 deluser(%args) -> [status, msg, result, meta]
 
-{en_US Delete user}.
+Delete user.
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -703,11 +699,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<etc_dir> => I<str> (default: "/etc")
 
-{en_US Location of passwd files}.
+Location of passwd files.
 
 =item * B<user> => I<str>
 
-{en_US User name}.
+User name.
 
 =back
 
@@ -751,9 +747,8 @@ Return value:  (any)
 
 =head2 setup_unix_user(%args) -> [status, msg, result, meta]
 
-{en_US Setup Unix user (existence, group memberships)}.
+Setup Unix user (existence, group memberships).
 
-{en_US 
 On do, will create Unix user if not already exists. And also make sure user
 belong to specified groups (and not belong to unwanted groups). Return the
 created UID/GID in the result.
@@ -761,7 +756,6 @@ created UID/GID in the result.
 On undo, will delete Unix user (along with its initially created home dir and
 files) if it was created by this function. Also will restore old group
 memberships.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -772,15 +766,15 @@ Arguments ('*' denotes required arguments):
 
 =item * B<create_home> => I<bool> (default: 1)
 
-{en_US Whether to create home directory when creating user}.
+Whether to create home directory when creating user.
 
 =item * B<etc_dir> => I<str> (default: "/etc")
 
-{en_US Location of passwd files}.
+Location of passwd files.
 
 =item * B<group> => I<str>
 
-{en_US Group name}.
+Group name.
 
 =item * B<max_gid> => I<any>
 
@@ -792,12 +786,10 @@ Arguments ('*' denotes required arguments):
 
 =item * B<member_of> => I<array[str]>
 
-{en_US List of Unix group names that the user must be member of}.
+List of Unix group names that the user must be member of.
 
-{en_US 
 If not specified, member_of will be set to just the primary group. The primary
 group will always be added even if not specified.
-}
 
 =item * B<min_gid> => I<any>
 
@@ -811,11 +803,9 @@ group will always be added even if not specified.
 
 =item * B<new_gid> => I<int>
 
-{en_US When creating group, use specific GID}.
+When creating group, use specific GID.
 
-{en_US 
 If not specified, will search an unused GID from C<min_gid> to C<max_gid>.
-}
 
 =item * B<new_home> => I<str>
 
@@ -833,35 +823,33 @@ If not specified, will search an unused GID from C<min_gid> to C<max_gid>.
 
 =item * B<new_uid> => I<int>
 
-{en_US Add with specified UID}.
+Add with specified UID.
 
-{en_US 
 If not specified, will search an unused UID from C<min_uid> to C<max_uid>.
-}
 
 =item * B<not_member_of> => I<array[str]>
 
-{en_US List of Unix group names that the user must NOT be member of}.
+List of Unix group names that the user must NOT be member of.
 
 =item * B<should_already_exist> => I<bool>
 
-{en_US Whether user should already exist}.
+Whether user should already exist.
 
 =item * B<should_exist> => I<bool> (default: 1)
 
-{en_US Whether user should exist}.
+Whether user should exist.
 
 =item * B<skel_dir> => I<str> (default: "/etc/skel")
 
-{en_US Directory to get skeleton files when creating user}.
+Directory to get skeleton files when creating user.
 
 =item * B<use_skel> => I<bool> (default: 1)
 
-{en_US Whether to copy files from skeleton dir when creating user}.
+Whether to copy files from skeleton dir when creating user.
 
 =item * B<user> => I<str>
 
-{en_US User name}.
+User name.
 
 =back
 
